@@ -8,10 +8,18 @@ pub enum Segment {
 	PriorityGroup(Vec<Capture>),
 }
 
-#[derive(Debug, Eq, PartialEq, Clone, Default)]
-pub struct Pattern {
-	pub starts: Option<String>,
-	pub ends: Option<String>,
+#[derive(Debug, Eq, PartialEq, Clone)]
+pub enum Pattern {
+	Eq {
+		any_of: Vec<String>,
+		no_case: bool,
+	},
+	Delimited {
+		starts: Vec<String>,
+		ends: Vec<String>,
+		no_case: bool,
+	},
+	Word,
 }
 
 #[derive(Clone, Eq, PartialEq, Debug)]
@@ -20,3 +28,9 @@ pub struct Capture {
 	pub quantifier: Quantifier,
 	pub patterns: Vec<Pattern>,
 }
+
+impl Pattern {
+	pub(crate) fn is_deterministic(&self) -> bool {
+		self != &Self::Word
+	}
+}
